# Getting Started with SAP LeanIX Architecture and Road Map Planning
### On this page
  * [Activate SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#activate-sap-leanix-architecture-and-road-map-planning)
  * [First Steps To Realize Value With SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#first-steps-to-realize-value-with-sap-leanix-architecture-and-road-map-planning)
  * [Pre-requisites](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#pre-requisites)
  * [Step 0. Identify the Scope and Stakeholders for Your First Architecture and Road Map Planning Scenario](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#step-0.-identify-the-scope-and-stakeholders-for-your-first-architecture-and-road-map-planning-scenario)
  * [Step 1. Create Your First Project Roadmap With Milestones](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#step-1.-create-your-first-project-roadmap-with-milestones)
  * [Step 2. Define the Transformations necessary to implement a Project](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#step-2.-define-the-transformations-necessary-to-implement-a-project)
  * [Step 3. Visualize the Impact of Your Transformations and Compare](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#step-3.-visualize-the-impact-of-your-transformations-and-compare)
  * [Step 4. Implement the Optimal Project and Execute Transformations](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#step-4.-implement-the-optimal-project-and-execute-transformations)
  * [Next steps](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning#next-steps)


Explore these foundational steps to kickstart your SAP LeanIX Architecture and Road Map Planning experience and begin the transformative process for your initiatives.
Welcome to the first steps in making the most of SAP LeanIX Architecture and Road Map Planning. On the preceding page, you learned what SAP LeanIX Architecture and Road Map Planning is and what it can do. This page focuses on how to use it and provides high-level instructions, outlining the initial steps to get started with SAP LeanIX Architecture and Road Map Planning.
